==> func_adl_servicex_xaodr22-2.0.1.22.2.107-py3-none-any.whl: func_adl_servicex_xaodr22/Muon/muonstationindex.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr22

_method_map = {
    'toStationIndex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'toStationIndex',
        'return_type': 'Muon::MuonStationIndex::StIndex',
    },
    'toLayerIndex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'toLayerIndex',
        'return_type': 'Muon::MuonStationIndex::LayerIndex',
    },
    'toChamberIndex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'toChamberIndex',
        'return_type': 'Muon::MuonStationIndex::ChIndex',
    },
    'phiName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'phiName',
        'return_type_element': '__gnu_cxx::__normal_iterator<char*,string>',
        'return_type_collection': 'const string',
    },
    'stName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'stName',
        'return_type_element': '__gnu_cxx::__normal_iterator<char*,string>',
        'return_type_collection': 'const string',
    },
    'chName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'chName',
        'return_type_element': '__gnu_cxx::__normal_iterator<char*,string>',
        'return_type_collection': 'const string',
    },
    'regionName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'regionName',
        'return_type_element': '__gnu_cxx::__normal_iterator<char*,string>',
        'return_type_collection': 'const string',
    },
    'layerName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'layerName',
        'return_type_element': '__gnu_cxx::__normal_iterator<char*,string>',
        'return_type_collection': 'const string',
    },
    'technologyName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'technologyName',
        'return_type_element': '__gnu_cxx::__normal_iterator<char*,string>',
        'return_type_collection': 'const string',
    },
    'sectorLayerHash': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'sectorLayerHash',
        'return_type': 'unsigned int',
    },
    'sectorLayerHashMax': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'sectorLayerHashMax',
        'return_type': 'unsigned int',
    },
    'numberOfSectors': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'numberOfSectors',
        'return_type': 'unsigned int',
    },
    'chIndex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'chIndex',
        'return_type': 'Muon::MuonStationIndex::ChIndex',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])
        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class MuonStationIndex:
    "A class"

    class ChIndex(Enum):
        ChUnknown = -1
        BIS = 0
        BIL = 1
        BMS = 2
        BML = 3
        BOS = 4
        BOL = 5
        BEE = 6
        EIS = 7
        EIL = 8
        EMS = 9
        EML = 10
        EOS = 11
        EOL = 12
        EES = 13
        EEL = 14
        CSS = 15
        CSL = 16
        ChIndexMax = 17

    class TechnologyIndex(Enum):
        TechnologyUnknown = -1
        MDT = 0
        CSCI = 1
        RPC = 2
        TGC = 3
        STGC = 4
        MM = 5
        TechnologyIndexMax = 6

    class StIndex(Enum):
        StUnknown = -1
        BI = 0
        BM = 1
        BO = 2
        BE = 3
        EI = 4
        EM = 5
        EO = 6
        EE = 7
        StIndexMax = 8

    class PhiIndex(Enum):
        PhiUnknown = -1
        BI1 = 0
        BI2 = 1
        BM1 = 2
        BM2 = 3
        BO1 = 4
        BO2 = 5
        T1 = 6
        T2 = 7
        T3 = 8
        T4 = 9
        CSC = 10
        STGC1 = 11
        STGC2 = 12
        PhiIndexMax = 13

    class LayerIndex(Enum):
        LayerUnknown = -1
        Inner = 0
        Middle = 1
        Outer = 2
        Extended = 3
        BarrelExtended = 4
        LayerIndexMax = 5

    class DetectorRegionIndex(Enum):
        DetectorRegionUnknown = -1
        EndcapA = 0
        Barrel = 1
        EndcapC = 2
        DetectorRegionIndexMax = 3


    def toStationIndex(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex) -> func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.StIndex:
        "A method"
        ...

    def toLayerIndex(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex) -> func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.LayerIndex:
        "A method"
        ...

    def toChamberIndex(self, region: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.DetectorRegionIndex, layer: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.LayerIndex, isSmall: bool) -> func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex:
        "A method"
        ...

    def phiName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.PhiIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def stName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.StIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def chName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def regionName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.DetectorRegionIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def layerName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.LayerIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def technologyName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.TechnologyIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def sectorLayerHash(self, detectorRegionIndex: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.DetectorRegionIndex, layerIndex: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.LayerIndex) -> int:
        "A method"
        ...

    def sectorLayerHashMax(self) -> int:
        "A method"
        ...

    def numberOfSectors(self) -> int:
        "A method"
        ...

    def chIndex(self, index: func_adl_servicex_xaodr22.str.str) -> func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex:
        "A method"
        ...

==> func_adl_servicex_xaodr22-2.1.1.22.2.107b2-py3-none-any.whl: func_adl_servicex_xaodr22/Muon/muonstationindex.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr22

_method_map = {
    'toStationIndex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'toStationIndex',
        'return_type': 'Muon::MuonStationIndex::StIndex',
    },
    'toLayerIndex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'toLayerIndex',
        'return_type': 'Muon::MuonStationIndex::LayerIndex',
    },
    'toChamberIndex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'toChamberIndex',
        'return_type': 'Muon::MuonStationIndex::ChIndex',
    },
    'phiName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'phiName',
        'return_type': 'const string',
    },
    'stName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'stName',
        'return_type': 'const string',
    },
    'chName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'chName',
        'return_type': 'const string',
    },
    'regionName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'regionName',
        'return_type': 'const string',
    },
    'layerName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'layerName',
        'return_type': 'const string',
    },
    'technologyName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'technologyName',
        'return_type': 'const string',
    },
    'sectorLayerHash': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'sectorLayerHash',
        'return_type': 'unsigned int',
    },
    'sectorLayerHashMax': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'sectorLayerHashMax',
        'return_type': 'unsigned int',
    },
    'numberOfSectors': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'numberOfSectors',
        'return_type': 'unsigned int',
    },
    'chIndex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'Muon::MuonStationIndex',
        'method_name': 'chIndex',
        'return_type': 'Muon::MuonStationIndex::ChIndex',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])


        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class MuonStationIndex:
    "A class"

    class ChIndex(Enum):
        ChUnknown = -1
        BIS = 0
        BIL = 1
        BMS = 2
        BML = 3
        BOS = 4
        BOL = 5
        BEE = 6
        EIS = 7
        EIL = 8
        EMS = 9
        EML = 10
        EOS = 11
        EOL = 12
        EES = 13
        EEL = 14
        CSS = 15
        CSL = 16
        ChIndexMax = 17

    class TechnologyIndex(Enum):
        TechnologyUnknown = -1
        MDT = 0
        CSCI = 1
        RPC = 2
        TGC = 3
        STGC = 4
        MM = 5
        TechnologyIndexMax = 6

    class StIndex(Enum):
        StUnknown = -1
        BI = 0
        BM = 1
        BO = 2
        BE = 3
        EI = 4
        EM = 5
        EO = 6
        EE = 7
        StIndexMax = 8

    class PhiIndex(Enum):
        PhiUnknown = -1
        BI1 = 0
        BI2 = 1
        BM1 = 2
        BM2 = 3
        BO1 = 4
        BO2 = 5
        T1 = 6
        T2 = 7
        T3 = 8
        T4 = 9
        CSC = 10
        STGC1 = 11
        STGC2 = 12
        PhiIndexMax = 13

    class LayerIndex(Enum):
        LayerUnknown = -1
        Inner = 0
        Middle = 1
        Outer = 2
        Extended = 3
        BarrelExtended = 4
        LayerIndexMax = 5

    class DetectorRegionIndex(Enum):
        DetectorRegionUnknown = -1
        EndcapA = 0
        Barrel = 1
        EndcapC = 2
        DetectorRegionIndexMax = 3


    def toStationIndex(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex) -> func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.StIndex:
        "A method"
        ...

    def toLayerIndex(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex) -> func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.LayerIndex:
        "A method"
        ...

    def toChamberIndex(self, region: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.DetectorRegionIndex, layer: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.LayerIndex, isSmall: bool) -> func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex:
        "A method"
        ...

    def phiName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.PhiIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def stName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.StIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def chName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def regionName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.DetectorRegionIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def layerName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.LayerIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def technologyName(self, index: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.TechnologyIndex) -> func_adl_servicex_xaodr22.str.str:
        "A method"
        ...

    def sectorLayerHash(self, detectorRegionIndex: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.DetectorRegionIndex, layerIndex: func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.LayerIndex) -> int:
        "A method"
        ...

    def sectorLayerHashMax(self) -> int:
        "A method"
        ...

    def numberOfSectors(self) -> int:
        "A method"
        ...

    def chIndex(self, index: func_adl_servicex_xaodr22.str.str) -> func_adl_servicex_xaodr22.Muon.muonstationindex.MuonStationIndex.ChIndex:
        "A method"
        ...
